pub struct ResourceProperty {
pub key: String,
pub value: NodePropertyValue,
}Fields
key: Stringvalue: NodePropertyValueTrait Implementations
Sourceimpl Clone for ResourceProperty
impl Clone for ResourceProperty
Sourcefn clone(&self) -> ResourceProperty
fn clone(&self) -> ResourceProperty
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResourceProperty
impl Debug for ResourceProperty
Sourceimpl<'a, ___E> Encode<ResourceProperty<'static>, ___E> for &'a ResourcePropertywhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<ResourceProperty<'static>, ___E> for &'a ResourcePropertywhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ResourceProperty<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ResourceProperty<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ResourceProperty<'static>, ___E> for ResourcePropertywhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<ResourceProperty<'static>, ___E> for ResourcePropertywhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ResourceProperty<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ResourceProperty<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ResourceProperty<'static>>, ___E> for &'a ResourceProperty
impl<'a, ___E> EncodeOption<Box<'static, ResourceProperty<'static>>, ___E> for &'a ResourceProperty
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ResourceProperty<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ResourceProperty<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ResourceProperty<'static>>, ___E> for ResourceProperty
impl<___E> EncodeOption<Box<'static, ResourceProperty<'static>>, ___E> for ResourceProperty
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ResourceProperty<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ResourceProperty<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ResourceProperty<'de>> for ResourceProperty
impl<'de> FromWire<ResourceProperty<'de>> for ResourceProperty
Sourcefn from_wire(wire: ResourceProperty<'de>) -> Self
fn from_wire(wire: ResourceProperty<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ResourceProperty<'de>> for ResourceProperty
impl<'de> FromWireRef<ResourceProperty<'de>> for ResourceProperty
Sourcefn from_wire_ref(wire: &ResourceProperty<'de>) -> Self
fn from_wire_ref(wire: &ResourceProperty<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ResourceProperty
impl Hash for ResourceProperty
Sourceimpl Ord for ResourceProperty
impl Ord for ResourceProperty
Sourcefn cmp(&self, other: &ResourceProperty) -> Ordering
fn cmp(&self, other: &ResourceProperty) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ResourceProperty
impl PartialEq for ResourceProperty
Sourcefn eq(&self, other: &ResourceProperty) -> bool
fn eq(&self, other: &ResourceProperty) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ResourceProperty
impl PartialOrd for ResourceProperty
impl Eq for ResourceProperty
impl StructuralPartialEq for ResourceProperty